@@ -3,6 +3,11 @@ Copyright (C) Nanosurf AG - All Rights Reserved (2021)
 License - MIT"""
 
 from nanosurf.lib.spm import *
+from nanosurf.lib.spm.studio import *
+
+class Studio(StudioScriptSession):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
 class SPM(Spm):
     def __init__(self, *args, **kwargs):
